@@ -1,5 +1,5 @@
 dctable.default <-
-function(x, ...) 
+function (x, ...) 
 {
     dct <- is.null(attr(x, "dctable"))
     ll <- length(list(...))
@@ -14,20 +14,22 @@ function(x, ...)
         dctmp <- lapply(obj, extractdctable.default)
         rnam <- lapply(dctmp, rownames)
         nam <- rnam[[1]]
-        if (!setequal(nam, unique(unlist(rnam))))
+        if (!setequal(nam, unique(unlist(rnam)))) 
             stop("parameter names in each model should be identical")
         rval <- vector("list", length(nam))
         names(rval) <- rownames(dctmp[[1]])
         Call <- match.call()
         mnam <- as.character(Call[-1])
         for (i in 1:length(nam)) {
-            rval[[i]] <- cbind(n.clones=k, t(sapply(dctmp, function(z) z[i,])))
-            if (length(mnam) > 1)
+            rval[[i]] <- cbind(n.clones = k, t(sapply(dctmp, 
+                function(z) z[i, ])))
+            if (length(mnam) > 1) 
                 rownames(rval[[i]]) <- mnam[ord]
             else rownames(rval[[i]]) <- deparse(substitute(x))
         }
-            rval <- lapply(rval, function(z) as.data.frame(z))
-    } else {
+        rval <- lapply(rval, function(z) as.data.frame(z))
+    }
+    else {
         rval <- attr(x, "dctable")
     }
     class(rval) <- "dctable"
